# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.26
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_app_sandbox_config_artifacts import AppAppSandboxConfigArtifacts

class TestAppAppSandboxConfigArtifacts(unittest.TestCase):
    """AppAppSandboxConfigArtifacts unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppAppSandboxConfigArtifacts:
        """Test AppAppSandboxConfigArtifacts
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppAppSandboxConfigArtifacts`
        """
        model = AppAppSandboxConfigArtifacts()
        if include_optional:
            return AppAppSandboxConfigArtifacts(
                cloudformation_stack_template = '',
                deprovision_policy = '',
                provision_policy = '',
                trust_policy = ''
            )
        else:
            return AppAppSandboxConfigArtifacts(
        )
        """

    def testAppAppSandboxConfigArtifacts(self):
        """Test AppAppSandboxConfigArtifacts"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
