# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_external_image_component_config import AppExternalImageComponentConfig

class TestAppExternalImageComponentConfig(unittest.TestCase):
    """AppExternalImageComponentConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppExternalImageComponentConfig:
        """Test AppExternalImageComponentConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppExternalImageComponentConfig`
        """
        model = AppExternalImageComponentConfig()
        if include_optional:
            return AppExternalImageComponentConfig(
                aws_ecr_image_config = nuon.models.app/awsecr_image_config.app.AWSECRImageConfig(
                    aws_region = '', 
                    component_config_id = '', 
                    component_config_type = '', 
                    created_at = '', 
                    created_by_id = '', 
                    iam_role_arn = '', 
                    id = '', 
                    updated_at = '', ),
                component_config_connection_id = '',
                created_at = '',
                created_by_id = '',
                id = '',
                image_url = '',
                tag = '',
                updated_at = ''
            )
        else:
            return AppExternalImageComponentConfig(
        )
        """

    def testAppExternalImageComponentConfig(self):
        """Test AppExternalImageComponentConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
