# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.service_create_terraform_module_component_config_request import ServiceCreateTerraformModuleComponentConfigRequest

class TestServiceCreateTerraformModuleComponentConfigRequest(unittest.TestCase):
    """ServiceCreateTerraformModuleComponentConfigRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceCreateTerraformModuleComponentConfigRequest:
        """Test ServiceCreateTerraformModuleComponentConfigRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceCreateTerraformModuleComponentConfigRequest`
        """
        model = ServiceCreateTerraformModuleComponentConfigRequest()
        if include_optional:
            return ServiceCreateTerraformModuleComponentConfigRequest(
                connected_github_vcs_config = nuon.models.service/connected_github_vcs_config_request.service.ConnectedGithubVCSConfigRequest(
                    branch = '', 
                    directory = '', 
                    git_ref = '', 
                    repo = '', ),
                env_vars = {
                    'key' : ''
                    },
                public_git_vcs_config = nuon.models.service/public_git_vcs_config_request.service.PublicGitVCSConfigRequest(
                    branch = '', 
                    directory = '', 
                    repo = '', ),
                variables = {
                    'key' : ''
                    },
                version = ''
            )
        else:
            return ServiceCreateTerraformModuleComponentConfigRequest(
                env_vars = {
                    'key' : ''
                    },
                variables = {
                    'key' : ''
                    },
        )
        """

    def testServiceCreateTerraformModuleComponentConfigRequest(self):
        """Test ServiceCreateTerraformModuleComponentConfigRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
